@@ -1,3 +1,4 @@
+mod circle;
 mod line;
 mod point;
 mod position;
@@ -5,6 +6,7 @@ mod rect;
 mod size;
 mod transform;
 
+pub use circle::*;
 pub use line::*;
 pub use point::*;
 pub use position::*;
